@@ -17,12 +17,10 @@ class Start:
 
     def start(self):
         print("💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻👩‍💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻")
-        print(
-            "...................😎 Starting Kubify Service 😎..................."
-        )
+        print("...................😎 Starting Kubify Service 😎...................")
         print("💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻💻")
-        playbooks=[f"{app_constants.ops_dir}/ansible/service.yaml"],
-        tags=[f"common,{app_constants.dir_path}"],
+        playbooks = ([f"{app_constants.ops_dir}/ansible/service.yaml"],)
+        tags = ([f"common,{app_constants.dir_path}"],)
         Options = namedtuple("Options", [])
         options = Options(verbosity=None, check=False, tags=tags, verbosity=1)
         # PlaybookExecutor(
